@@ -2,7 +2,7 @@
 """ This module is named python module.py and bring you function print_lol. In this function, you can find list
       type element and show them as data."""
 
-def print_lol(the_list, level) :
+def print_lol(the_list, level=0) :
     for each_item in the_list :
         if isinstance(each_item, list) :
             print_lol(each_item, level + 1)
